@@ -1,3 +1,24 @@
+"""
+Copyright 2023 fretgfr
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+"""
 from __future__ import annotations
 
 from datetime import datetime
@@ -519,7 +540,7 @@ class Client:
 
     async def upload_file(
         self,
-        file: UploadFile,
+        payload: FileUploadPayload,
         *,
         format: NameFormat = NameFormat.uuid,
         compression_percent: int = 0,
@@ -531,12 +552,12 @@ class Client:
         text: bool = False,
         override_name: Optional[str] = None,
         original_name: Optional[str] = None,
-    ) -> UploadResponse:
+    ) -> FileUploadResponse:
         """Uploads a File to zipline
 
         Parameters
         ----------
-        file : UploadFile
+        payload : UploadFile
             The file to upload.
         format : NameFormat, optional
             The format of the name to assign to the uploaded File, by default NameFormat.uuid
@@ -561,7 +582,7 @@ class Client:
 
         Returns
         -------
-        UploadResponse
+        FileUploadResponse
             The uploaded File
 
         Raises
@@ -595,13 +616,13 @@ class Client:
         }
 
         formdata = aiohttp.FormData()
-        formdata.add_field("file", file.data, filename=file.filename, content_type=file.mimetype)
+        formdata.add_field("file", payload.data, filename=payload.filename, content_type=payload.mimetype)
 
         async with self._session.post("/api/upload", headers=headers, data=formdata) as resp:
             status = resp.status
             if status == 200:
                 js = await resp.json()
-                return UploadResponse._from_data(js)
+                return FileUploadResponse._from_data(js)
 
             elif status == 400:
                 js = await resp.json()
