@@ -108,7 +108,7 @@ class File:
         bytes
             The data of the File
         """
-        async with self._session.get(self.url) as resp:
+        async with self._session.get(self.full_url) as resp:
             return await resp.read()
 
     async def delete(self) -> None:
@@ -163,6 +163,10 @@ class File:
 
         raise UnhandledError(f"Code {status} unhandled in File.delete!")
 
+    @property
+    def full_url(self) -> str:
+        """Returns the full URL of this File."""
+        return f"{self._session._base_url}{self.url}"
 
 @dataclass(slots=True)
 class User:
@@ -437,7 +441,7 @@ class ShortenedURL:
 
 
 class FileUploadResponse(NamedTuple):
-    """Represents a Zipline invite.
+    """Represents a response to a File upload.
 
     Fields
     --------
